###
### R routines for the R package mvmeta (c) Antonio Gasparrini 2012-2013
#
`vcov.mvmeta` <-
function(object, ...) {
#
################################################################################
#
  return(object$vcov)
}

